@@ -3,7 +3,7 @@ package Full::Pragmata;
 use strict;
 use warnings;
 
-our $VERSION = '1.003'; # VERSION
+our $VERSION = '1.004'; # VERSION
 our $AUTHORITY = 'cpan:TEAM'; # AUTHORITY
 
 use utf8;
@@ -266,7 +266,7 @@ sub import ($called_on, $version_tag, %args) {
     List::Util->export($pkg => qw(uniqstr));
     # eval "package $pkg; use Object::Pad::FieldAttr::Checked; use Data::Checks qw(NumGE); 1" or die $@;
     Object::Pad::FieldAttr::Checked->import($pkg);
-    Sublike::Extended->import($pkg);
+    Sublike::Extended->import;
     Signature::Attribute::Checked->import($pkg);
     Data::Checks->import(qw(
         Defined
